@@ -1,4 +1,5 @@
 from django import forms
+
 from ...models.collection import FileItem, ImageItem
 from .base import UploadedFileBaseForm
 
@@ -6,15 +7,15 @@ from .base import UploadedFileBaseForm
 class FileItemDialog(UploadedFileBaseForm):
     class Meta:
         model = FileItem
-        fields = ('new_name', 'display_name')
+        fields = ("new_name", "display_name")
 
 
 class ImageItemDialog(UploadedFileBaseForm):
     class Meta:
         model = ImageItem
-        fields = ('new_name', 'title', 'description')
+        fields = ("new_name", "title", "description")
         widgets = {
-            'description': forms.Textarea(attrs={
-                'rows': 3
+            "description": forms.Textarea(attrs={
+                "rows": 3
             })
         }
